@@ -14,7 +14,6 @@ class File(object):
     def __init__(
         self,
         path: Union[PurePath, str],
-        block_size: int = UNITS["MiB"],
         start_pos: int = os.SEEK_SET,
         remote: bool = False,
         hostname: str = None,
@@ -31,9 +30,7 @@ class File(object):
             raise ValueError("Invalid ssh encryption algorithm")
 
         self.path = path
-        self.block_size = block_size
         self.start_pos = start_pos
-        self.size: int = 0
         self.remote = remote
         self.ssh_options: Dict[str, Any] = {
             "hostname": hostname,
@@ -50,8 +47,8 @@ class File(object):
         self._local = threading.local()
 
     def __repr__(self):
-        return "<blocksync.File path={} block_size={} state={}>".format(
-            self.path, self.block_size, "opened" if self.opened else "closed",
+        return "<blocksync.File path={} state={}>".format(
+            self.path, "opened" if self.opened else "closed",
         )
 
     def open_sftp(self, session: paramiko.SSHClient = None) -> "File":
@@ -89,9 +86,6 @@ class File(object):
             return self
 
         self._local.io = self._open(mode="rb+")
-        self.size = self.execute("seek", os.SEEK_SET, os.SEEK_END).execute_with_result(
-            "tell"
-        )
         self.execute("seek", os.SEEK_SET)
         return self
 
@@ -99,15 +93,15 @@ class File(object):
         if self.opened:
             if flush:
                 self._local.io.flush()
-            self._local.io = None
+            self._local.io.close()
 
         if self.remote and self.connected and close_sftp:
             self.close_sftp()
         return self
 
-    def get_blocks(self) -> Any:
+    def get_blocks(self, block_size: int = UNITS["MiB"]) -> Any:
         while self.opened:
-            if block := self._local.io.read(self.block_size):
+            if block := self._local.io.read(block_size):
                 yield block
             else:
                 break  # pragma: no cover
@@ -136,7 +130,7 @@ class File(object):
     @property
     def connected(self) -> bool:
         if (
-            getattr(self._local, "ssh", False)
+            hasattr(self._local, "ssh")
             and isinstance(self._local.ssh, paramiko.SSHClient)
             and self._local.ssh.get_transport() is not None
         ):
@@ -145,8 +139,16 @@ class File(object):
 
     @property
     def opened(self) -> bool:
-        try:
-            self._local.io.tell()
-            return True
-        except:
-            return False
+        if hasattr(self._local, "io"):
+            if hasattr(self._local.io, "_closed"):
+                return not self._local.io._closed
+            return not self._local.io.closed
+        return False
+
+    @property
+    def size(self) -> int:
+        if self.remote:
+            _stat = self._local.sftp.stat
+        else:
+            _stat = os.stat
+        return _stat(self.path).st_size
