@@ -1,7 +1,9 @@
+import random
+import string
 from inspect import signature
 from typing import Callable
 
-__all__ = ["validate_callback"]
+__all__ = ["validate_callback", "generate_random_data"]
 
 
 def validate_callback(c: Callable, n: int = 0) -> bool:
@@ -16,3 +18,7 @@ def validate_callback(c: Callable, n: int = 0) -> bool:
             )
         return True
     raise TypeError("{} is not callable".format(c))
+
+
+def generate_random_data(size: int) -> str:
+    return "".join(random.choices(string.ascii_letters + string.digits, k=size))
